@@ -5,15 +5,15 @@ Simulation Network simunet
 import datetime
 from simunetcore.serializer import Serializer
 from simunetcore.model import Model
-from simunetcore.rest import RestModel
+from simunetcore.rest import RESTModel
 from simunetcore.mqtt import MQTTModel
 from simunetcore.aws import AWSModel
 from simunetcore.waveform import Waveform
 from simunetcore.factory import Factory
 
-__all__ = ["Serializer", "Model", "RestModel", "MQTTModel", "AWSModel", "Waveform", "Factory"]
+__all__ = ["Serializer", "Model", "RESTModel", "MQTTModel", "AWSModel", "Waveform", "Factory"]
 __title__ = "simunetcore"
-__version__ = "0.0.1"
+__version__ = "0.0.6"
 __license__ = "MIT License"
 __copyright__ = "core simunet team and contributors".format(datetime.date.today().year)
 
