@@ -3,7 +3,7 @@ import types
 from simunetcore import Model
 from simunetcore import MQTTModel
 from simunetcore import AWSModel
-from simunetcore import RestModel
+from simunetcore import RESTModel
 from simunetcore import logger
         
 class Factory(dict):
@@ -13,16 +13,16 @@ class Factory(dict):
         """
         Creates a new factory object and 
         registers the core simunet models 
-        (AWSModel, MQTTModel and RestModel).
+        (AWSModel, MQTTModel and RESTModel).
  
         """
         super().__init__()
        
         self["AWSModel"] = AWSModel
         self["MQTTModel"] = MQTTModel
-        self["RestModel"] = RestModel
+        self["RESTModel"] = RESTModel
 
-    def register(self, code, namespace = "simunet.factory"):
+    def register(self, code, namespace = "simunetcore.factory"):
         """
         Rergisters a peice of code as a model in the factory 
         under the the given namespace.
@@ -37,7 +37,7 @@ class Factory(dict):
             For example Registering a class `TestModel` 
             in the namespace `my.models`  leads to the 
             dict entry: {'Test': <class 'my.models.TestModel'>}.
-            Default = 'simunet.factory'.
+            Default = 'simunetcore.factory'.
 
         """            
                     # create a factory module
